#
# spec file for package ghc-unordered-containers
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name unordered-containers
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.2.16.0
Release:        bp154.1.11
Summary:        Efficient hashing-based container types
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-rpm-macros
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-ChasingBottoms-devel
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-random-devel
BuildRequires:  ghc-test-framework-devel
BuildRequires:  ghc-test-framework-hunit-devel
BuildRequires:  ghc-test-framework-quickcheck2-devel
%endif

%description
Efficient hashing-based container types. The containers have been optimized for
performance critical use, both in terms of large data quantities and high
speed.

The declared cost of each operation is either worst-case or amortized, but
remains valid even if structures are shared.

/Security/

This package currently provides no defenses against hash collision attacks such
as HashDoS. Users who need to store input from untrusted sources are advised to
use 'Data.Map' or 'Data.Set' from the 'containers' package instead.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGES.md

%changelog
* Mon Dec  6 2021 Peter Simons <psimons@suse.com>
- Update unordered-containers to version 0.2.16.0.
  [#]# [0.2.16.0]
  * [Increase maximum branching factor from 16 to 32](https://github.com/haskell-unordered-containers/unordered-containers/pull/317)
  * [Tweak `union.goDifferentHash`](https://github.com/haskell-unordered-containers/unordered-containers/pull/277)
  * [Fix debug mode bounds check in `cloneM`](https://github.com/haskell-unordered-containers/unordered-containers/pull/331)
  * [Remove some old internal compatibility code](https://github.com/haskell-unordered-containers/unordered-containers/pull/334)
  [0.2.16.0]: https://github.com/haskell-unordered-containers/unordered-containers/compare/v0.2.15.0...v0.2.16.0
* Wed Nov 10 2021 psimons@suse.com
- Update unordered-containers to version 0.2.15.0.
  [#]# [0.2.15.0]
  * [Add security advisory regarding hash collision attacks](https://github.com/haskell-unordered-containers/unordered-containers/pull/320)
  * [Add support for hashable 1.4](https://github.com/haskell-unordered-containers/unordered-containers/pull/324)
  * [Drop support for GHC < 8](https://github.com/haskell-unordered-containers/unordered-containers/pull/323)
  [0.2.15.0]: https://github.com/haskell-unordered-containers/unordered-containers/compare/v0.2.14.0...v0.2.15.0
* Sat May 22 2021 psimons@suse.com
- Update unordered-containers to version 0.2.14.0.
  [#]# [0.2.14.0]
  * [Add `HashMap.mapKeys`.](https://github.com/haskell-unordered-containers/unordered-containers/pull/308) Thanks, Marco Perone!
  * [Add instances for `NFData1` and `NFData2`.](https://github.com/haskell-unordered-containers/unordered-containers/pull/314) Thanks, Isaac Elliott and Oleg Grenrus!
  * [Fix `@since`-annotation for `compose`.](https://github.com/haskell-unordered-containers/unordered-containers/pull/303) Thanks, @Mathnerd314!
  [0.2.14.0]: https://github.com/haskell-unordered-containers/unordered-containers/compare/v0.2.13.0...v0.2.14.0
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Oct  6 2020 psimons@suse.com
- Update unordered-containers to version 0.2.13.0.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/unordered-containers-0.2.13.0/src/CHANGES.md
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Wed Aug  5 2020 psimons@suse.com
- Update unordered-containers to version 0.2.12.0.
  [#]# [0.2.12.0]
  * Add `HashMap.isSubmapOf[By]` and `HashSet.isSubsetOf`. Thanks Sven Keidel. ([#282])
  * Expose internal modules. ([#283])
  * Documentation improvements in `Data.HashSet`, including a beginner-friendly
    introduction. Thanks Matt Renaud. ([#267])
  * `HashMap[.Strict].alterF`: Skip key deletion for absent keys. ([#288])
  * Remove custom `unsafeShift{L,R}` definitions. ([#281])
  * Various other documentation improvements.
  [0.2.12.0]: https://github.com/haskell-unordered-containers/unordered-containers/compare/v0.2.11.0...v0.2.12.0
  [#267]: https://github.com/haskell-unordered-containers/unordered-containers/pull/267
  [#281]: https://github.com/haskell-unordered-containers/unordered-containers/pull/281
  [#282]: https://github.com/haskell-unordered-containers/unordered-containers/pull/282
  [#283]: https://github.com/haskell-unordered-containers/unordered-containers/pull/283
  [#288]: https://github.com/haskell-unordered-containers/unordered-containers/pull/288
* Thu Jun 18 2020 psimons@suse.com
- Update unordered-containers to version 0.2.11.0.
  [#]# 0.2.11.0
  * Add `HashMap.findWithDefault` (soft-deprecates `HashMap.lookupDefault`).
    Thanks, Matt Renaud.
  * Add `HashMap.fromListWithKey`. Thanks, Josef Svenningsson.
  * Add more folding functions and use them in `Foldable` instances. Thanks,
    David Feuer.
  * Add `HashMap.!?`, a flipped version of `lookup`. Thanks, Matt Renaud.
  * Add a `Bifoldable` instance for `HashMap`. Thanks, Joseph Sible.
  * Add a `HasCallStack` constraint to `(!)`. Thanks, Roman Cheplyaka.
  [#]## Bug fixes
  * Fix a space leak affecting updates on keys with hash collisions. Thanks,
    Neil Mitchell. ([#254])
  * Get rid of some silly thunks that could be left lying around. ([#232]).
    Thanks, David Feuer.
  [#]## Other changes
  * Speed up the `Hashable` instances for `HashMap` and `HashSet`. Thanks,
    Edward Amsden.
  * Remove a dependency cycle hack from the benchmark suite. Thanks,
    Andrew Martin.
  * Improve documentation. Thanks, Tristan McLeay, Li-yao Xia, Gareth Smith,
    Simon Jakobi, Sergey Vinokurov, and likely others.
  [#232]: https://github.com/haskell-unordered-containers/unordered-containers/issues/232
  [#254]: https://github.com/haskell-unordered-containers/unordered-containers/issues/254
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Tue Jun 11 2019 Peter Simons <psimons@suse.com>
- Update Cabal file for more accurate build dependencies.
* Sat Jan 19 2019 psimons@suse.com
- Update unordered-containers to version 0.2.10.0.
  [#]# 0.2.10.0
  * Add `HashMap.alterF`.
  * Add `HashMap.keysSet`.
  * Make `HashMap.Strict.traverseWithKey` force the results before
    installing them in the map.
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update unordered-containers to version 0.2.9.0.
  * Add `Ord/Ord1/Ord2` instances. (Thanks, Oleg Grenrus)
  * Use `SmallArray#` instead of `Array#` for GHC versions 7.10 and above.
    (Thanks, Dmitry Ivanov)
  * Adjust for `Semigroup => Monoid` proposal implementation.
    (Thanks, Ryan Scott)
  * Fix a strictness bug in `fromListWith`.
  * Enable eager blackholing for pre-8.2 GHC versions to work around
    a runtime system bug. (Thanks, Ben Gamari)
  * Avoid sketchy reimplementation of `ST` when compiling with recent
    GHC.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Mon Mar 27 2017 psimons@suse.com
- Update to version 0.2.8.0 with cabal2obs.
* Sun Jan  8 2017 psimons@suse.com
- Update to version 0.2.7.2 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.2.7.1 revision 0 with cabal2obs.
* Fri Jun 10 2016 mimi.vx@gmail.com
- update to 0.2.7.1
- remove useless _service
  * Fix linker error related to popcnt.
* Sat Feb 20 2016 mimi.vx@gmail.com
- update to 0.2.7.0
  * support criterion-1.1
  * Add unionWithKey for hash maps.
* Tue Feb 16 2016 mimi.vx@gmail.com
- update to 0.2.6.0
  * Mark several modules as Trustworthy.
  * Add Hashable instances for HashMap and HashSet.
  * Add mapMaybe, mapMaybeWithKey, update, alter, and intersectionWithKey.
  * Add roles.
  * Add Hashable and Semigroup instances.
* Tue Apr 14 2015 mimi.vx@gmail.com
- update to 0.2.5.1
  * no changelog
* Fri Sep 12 2014 peter.trommler@ohm-hochschule.de
- update to 0.2.4.0
  * no changelog
  * Haskell Platform 2014.2.0.0
* Tue Sep  2 2014 peter.trommler@ohm-hochschule.de
- regenerate spec file
* Sat Aug 23 2014 peter.trommler@ohm-hochschule.de
- enable PowerPC builds
- reorganize spec file
* Mon May  6 2013 peter.trommler@ohm-hochschule.de
- more transparent packaging (fewer macros)
* Sat Mar 23 2013 peter.trommler@ohm-hochschule.de
- update to 0.2.3.0 from upstream
- prepare for Factory submission
  * copyright notice
  * service localonly
  * expand macro in name tag
* Wed Apr 18 2012 peter.trommler@ohm-hochschule.de
- Initial packaging.
